#pragma once

#include <maya/MPxCommand.h>
#include <maya/MGlobal.h>
#include <maya/MStatus.h>
#include <maya/MArgList.h>
#include <maya/MString.h>
#include <maya/MSelectionList.h>
#include <maya/MItSelectionList.h>
#include <maya/MDagPath.h>
#include <maya/MFnMesh.h>
#include <maya/MMatrix.h>
#include <maya/MFnMesh.h>
#include <maya/MFloatPointArray.h>
#include <maya/MItMeshPolygon.h>
#include <maya/MIntArray.h>
#include <maya/MFloatVector.h>
//#include <maya

#include <fstream>
#include <vector>

class CSimpleExporterCMD : public MPxCommand
{
public:
	static void *creator() 
	{ 
		return new CSimpleExporterCMD();
	}

	virtual MStatus doIt(const MArgList &args)
	{
		if(!args.length())
			return MS::kFailure;
		MString file_name = args.asString(0);
		std::fstream out(file_name.asChar(), std::ios::out);
		MSelectionList slist;
		MGlobal::getActiveSelectionList(slist);
		if(!slist.length())
		{
			out.close();
			return MS::kSuccess;
		}
		MItSelectionList iter(slist, MFn::kMesh);

		std::vector<MDagPath> path_vec;
		for(;!iter.isDone(); iter.next())
		{
			MDagPath path;
			if(iter.getDagPath(path))
				path_vec.push_back(path);
		}
		if(!path_vec.size())
		{
			out.close();
			return MS::kSuccess;
		}
		for(std::vector<MDagPath>::iterator it = path_vec.begin(); it != path_vec.end(); ++it)
		{
			MDagPath path = *it;
			MFnMesh mesh(path);
			MFloatPointArray points;
			mesh.getPoints(points, MSpace::kObject);
			MItMeshPolygon poly_iter(mesh.object());
			out << "\nObject " << mesh.name() << " \n{\n";
			out << "\ttransform " << path.inclusiveMatrix() << "\n\tgeometry:\n";
			for(register size_t i = 0; i < points.length(); ++i)
			{
				out << "\t" << MFloatVector(points[i]) << "\n";
			}
			out << "\tindices:\n";
			for(;!poly_iter.isDone(); poly_iter.next())
			{
				MIntArray indices;
				poly_iter.getVertices(indices);
				out << "\t";
				for(register size_t i = 0; i < indices.length(); ++i)
				{
					out << indices[i] << " ";
				}
				out << "\n";
			}
			out << "}\n";
			out.flush();
		}
		out.close();

		return MS::kSuccess;
	}
};